/*
 * Copyright © 2006 Carl Worth
 *
 * This program is free software; you can redistribute it and\/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA."
 */

#include "word-game.h"

#include <string.h>
#include <ctype.h>
#include <sys/time.h>
#include <time.h>

static int
character_compare (const void *_a,
		   const void *_b)
{
    const char *a = _a;
    const char *b = _b;

    if (*a == '?')
	return 1;
    if (*b == '?')
	return -1;
    return *a - *b;
}

int
main (void)
{
    dict_t dict, solution;
    struct timeval tv;
    bag_t bag;
    char rack[8];

    gettimeofday (&tv, NULL);
    srand (tv.tv_sec ^ tv.tv_usec);

    bag_init (&bag);
    bag_shuffle (&bag);

    memcpy (rack, bag.tiles, 7);
    rack[7] = '\0';
    qsort (rack, 7, 1, character_compare);

    dict_init (&dict);
    dict_add_words_from_file (&dict, "words.txt");

    dict_init (&solution);
    subanagram_expand (rack, &dict, &solution);

    word_game_play (rack, &dict, &solution, 0);

    dict_fini (&solution);
    dict_fini (&dict);

    return 0;
}
